@@ -12,7 +12,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::NextVersion;
 # ABSTRACT: Provide a version number by bumping the last git release tag
 
-our $VERSION = '2.041';
+our $VERSION = '2.043';
 
 use Dist::Zilla 4 ();
 use version 0.80 ();
@@ -40,12 +40,12 @@ use constant _CoercedRegexp => do {
     $tc;
 };
 
-has version_regexp  => ( is => 'ro', isa=> _CoercedRegexp, coerce => 1,
+has version_regexp  => ( is => 'ro', isa => _CoercedRegexp, coerce => 1,
                          default => sub { qr/^v(.+)$/ } );
 
-has first_version  => ( is => 'ro', isa=>Str, default => '0.001' );
+has first_version  => ( is => 'ro', isa => Str, default => '0.001' );
 
-has version_by_branch  => ( is => 'ro', isa=>Bool, default => 0 );
+has version_by_branch  => ( is => 'ro', isa => Bool, default => 0 );
 
 sub _versions_from_tags {
   my ($regexp, $tags) = @_;
@@ -56,7 +56,9 @@ sub _versions_from_tags {
 } # end _versions_from_tags
 
 has _all_versions => (
-  is => 'ro',  isa=>ArrayRef,  init_arg => undef,  lazy => 1,
+  is => 'ro',  isa => ArrayRef,
+  init_arg => undef,
+  lazy => 1,
   default => sub {
     my $self = shift;
     my $v = _versions_from_tags($self->version_regexp, [ $self->git->tag ]);
@@ -133,6 +135,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         (map { $_ => $self->$_ } qw(version_regexp first_version)),
         version_by_branch => $self->version_by_branch ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -205,7 +208,7 @@ Dist::Zilla::Plugin::Git::NextVersion - Provide a version number by bumping the
 
 =head1 VERSION
 
-version 2.041
+version 2.043
 
 =head1 SYNOPSIS
 
@@ -283,7 +286,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-L<http://www.listbox.com/subscribe/?list_id=139292>.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
