@@ -13,7 +13,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Tag;
 # ABSTRACT: Tag the new version
 
-our $VERSION = '2.041';
+our $VERSION = '2.043';
 
 use Moose;
 use MooseX::Has::Sugar;
@@ -68,6 +68,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         (map { $_ => $self->$_ } qw(tag_format tag_message changelog branch tag)),
         signed => $self->signed ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -99,6 +100,7 @@ sub after_release {
     $self->log("Tagged $tag");
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -113,7 +115,7 @@ Dist::Zilla::Plugin::Git::Tag - Tag the new version
 
 =head1 VERSION
 
-version 2.041
+version 2.043
 
 =head1 SYNOPSIS
 
@@ -180,7 +182,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-L<http://www.listbox.com/subscribe/?list_id=139292>.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
